==> jc-1.4.0.tar.gz: gnu/java/net/EmptyX509TrustManager.h <==
// public class gnu.java.net.EmptyX509TrustManager

// class file dependencies
// @dep_class da6b6e28bb89b836 gnu_java_net_EmptyX509TrustManager
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_java_net_EmptyX509TrustManager_H_
#define _JC_gnu_java_net_EmptyX509TrustManager_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_gnu_java_net_EmptyX509TrustManager$sub_refs	_jc_gnu_java_net_EmptyX509TrustManager$sub_refs;
typedef struct _jc_gnu_java_net_EmptyX509TrustManager$sub_nonrefs	_jc_gnu_java_net_EmptyX509TrustManager$sub_nonrefs;
typedef struct _jc_gnu_java_net_EmptyX509TrustManager$refs	_jc_gnu_java_net_EmptyX509TrustManager$refs;
typedef struct _jc_gnu_java_net_EmptyX509TrustManager$nonrefs	_jc_gnu_java_net_EmptyX509TrustManager$nonrefs;
typedef struct _jc_gnu_java_net_EmptyX509TrustManager$object	_jc_gnu_java_net_EmptyX509TrustManager$object;

typedef const struct _jc_gnu_java_net_EmptyX509TrustManager$vmethods	_jc_gnu_java_net_EmptyX509TrustManager$vmethods;
typedef const struct _jc_gnu_java_net_EmptyX509TrustManager$vtable	_jc_gnu_java_net_EmptyX509TrustManager$vtable;
typedef const struct _jc_gnu_java_net_EmptyX509TrustManager$vtype	_jc_gnu_java_net_EmptyX509TrustManager$vtype;

// Constructors
extern void _jc_gnu_java_net_EmptyX509TrustManager$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_java_net_EmptyX509TrustManager$object *);

// Virtual methods
extern void _jc_gnu_java_net_EmptyX509TrustManager$method$checkClientTrusted$f892aff829752d9c(_jc_env *, struct _jc_gnu_java_net_EmptyX509TrustManager$object *, struct _jc_object_array *, struct _jc_java_lang_String$object *);
extern void _jc_gnu_java_net_EmptyX509TrustManager$method$checkServerTrusted$4b6891a5e7537c28(_jc_env *, struct _jc_gnu_java_net_EmptyX509TrustManager$object *, struct _jc_object_array *, struct _jc_java_lang_String$object *);
extern _jc_object_array *_jc_gnu_java_net_EmptyX509TrustManager$method$getAcceptedIssuers$15d644057d13db99(_jc_env *, struct _jc_gnu_java_net_EmptyX509TrustManager$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_net_EmptyX509TrustManager$method_info$checkClientTrusted$f892aff829752d9c;
extern _jc_method _jc_gnu_java_net_EmptyX509TrustManager$method_info$checkServerTrusted$4b6891a5e7537c28;
extern _jc_method _jc_gnu_java_net_EmptyX509TrustManager$method_info$getAcceptedIssuers$15d644057d13db99;

// Virtual methods structure
struct _jc_gnu_java_net_EmptyX509TrustManager$vmethods {
	void	(*checkClientTrusted$f892aff829752d9c)(_jc_env *, struct _jc_gnu_java_net_EmptyX509TrustManager$object *, struct _jc_object_array *, struct _jc_java_lang_String$object *);
	void	(*checkServerTrusted$4b6891a5e7537c28)(_jc_env *, struct _jc_gnu_java_net_EmptyX509TrustManager$object *, struct _jc_object_array *, struct _jc_java_lang_String$object *);
	_jc_object_array	*(*getAcceptedIssuers$15d644057d13db99)(_jc_env *, struct _jc_gnu_java_net_EmptyX509TrustManager$object *);
};

// Vtable
struct _jc_gnu_java_net_EmptyX509TrustManager$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_net_EmptyX509TrustManager$vmethods	gnu_java_net_EmptyX509TrustManager;
};

// Vtype
struct _jc_gnu_java_net_EmptyX509TrustManager$vtype {
	_jc_type			type;
	_jc_gnu_java_net_EmptyX509TrustManager$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_net_EmptyX509TrustManager$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_net_EmptyX509TrustManager$refs {
    _jc_gnu_java_net_EmptyX509TrustManager$sub_refs	gnu_java_net_EmptyX509TrustManager;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_net_EmptyX509TrustManager$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_net_EmptyX509TrustManager$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_net_EmptyX509TrustManager$sub_nonrefs	gnu_java_net_EmptyX509TrustManager;
};

// Object instance structure
struct _jc_gnu_java_net_EmptyX509TrustManager$object {
	_jc_gnu_java_net_EmptyX509TrustManager$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_net_EmptyX509TrustManager$vtype	*vtype;
	_jc_gnu_java_net_EmptyX509TrustManager$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_net_EmptyX509TrustManager$vtype _jc_gnu_java_net_EmptyX509TrustManager$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_net_EmptyX509TrustManager, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_net_EmptyX509TrustManager$class_object;

#endif	/* _JC_gnu_java_net_EmptyX509TrustManager_H_ */

==> jc-1.4.6.tar.gz: gnu/java/net/EmptyX509TrustManager.h <==
// public class gnu.java.net.EmptyX509TrustManager

// class file dependencies
// @dep_class a91f2b9aa78e378b gnu_java_net_EmptyX509TrustManager
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_java_net_EmptyX509TrustManager_H_
#define _JC_gnu_java_net_EmptyX509TrustManager_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_gnu_java_net_EmptyX509TrustManager$sub_refs	_jc_gnu_java_net_EmptyX509TrustManager$sub_refs;
typedef struct _jc_gnu_java_net_EmptyX509TrustManager$sub_nonrefs	_jc_gnu_java_net_EmptyX509TrustManager$sub_nonrefs;
typedef struct _jc_gnu_java_net_EmptyX509TrustManager$refs	_jc_gnu_java_net_EmptyX509TrustManager$refs;
typedef struct _jc_gnu_java_net_EmptyX509TrustManager$nonrefs	_jc_gnu_java_net_EmptyX509TrustManager$nonrefs;
typedef struct _jc_gnu_java_net_EmptyX509TrustManager$object	_jc_gnu_java_net_EmptyX509TrustManager$object;

typedef const struct _jc_gnu_java_net_EmptyX509TrustManager$vmethods	_jc_gnu_java_net_EmptyX509TrustManager$vmethods;
typedef const struct _jc_gnu_java_net_EmptyX509TrustManager$vtable	_jc_gnu_java_net_EmptyX509TrustManager$vtable;
typedef const struct _jc_gnu_java_net_EmptyX509TrustManager$vtype	_jc_gnu_java_net_EmptyX509TrustManager$vtype;

// Constructors
extern void _jc_gnu_java_net_EmptyX509TrustManager$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_java_net_EmptyX509TrustManager$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_gnu_java_net_EmptyX509TrustManager$method$checkClientTrusted$f892aff829752d9c(_jc_env *, struct _jc_gnu_java_net_EmptyX509TrustManager$object *, struct _jc_object_array *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_java_net_EmptyX509TrustManager$method$checkServerTrusted$4b6891a5e7537c28(_jc_env *, struct _jc_gnu_java_net_EmptyX509TrustManager$object *, struct _jc_object_array *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern _jc_object_array *_jc_gnu_java_net_EmptyX509TrustManager$method$getAcceptedIssuers$15d644057d13db99(_jc_env *, struct _jc_gnu_java_net_EmptyX509TrustManager$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_net_EmptyX509TrustManager$method_info$checkClientTrusted$f892aff829752d9c;
extern _jc_method _jc_gnu_java_net_EmptyX509TrustManager$method_info$checkServerTrusted$4b6891a5e7537c28;
extern _jc_method _jc_gnu_java_net_EmptyX509TrustManager$method_info$getAcceptedIssuers$15d644057d13db99;

// Virtual methods structure
struct _jc_gnu_java_net_EmptyX509TrustManager$vmethods {
	void	(*checkClientTrusted$f892aff829752d9c)(_jc_env *, struct _jc_gnu_java_net_EmptyX509TrustManager$object *, struct _jc_object_array *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
	void	(*checkServerTrusted$4b6891a5e7537c28)(_jc_env *, struct _jc_gnu_java_net_EmptyX509TrustManager$object *, struct _jc_object_array *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
	_jc_object_array	*(*getAcceptedIssuers$15d644057d13db99)(_jc_env *, struct _jc_gnu_java_net_EmptyX509TrustManager$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_net_EmptyX509TrustManager$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_net_EmptyX509TrustManager$vmethods	gnu_java_net_EmptyX509TrustManager;
};

// Vtype
struct _jc_gnu_java_net_EmptyX509TrustManager$vtype {
	_jc_type			type;
	_jc_gnu_java_net_EmptyX509TrustManager$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_net_EmptyX509TrustManager$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_net_EmptyX509TrustManager$refs {
    _jc_gnu_java_net_EmptyX509TrustManager$sub_refs	gnu_java_net_EmptyX509TrustManager;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_net_EmptyX509TrustManager$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_net_EmptyX509TrustManager$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_net_EmptyX509TrustManager$sub_nonrefs	gnu_java_net_EmptyX509TrustManager;
};

// Object instance structure
struct _jc_gnu_java_net_EmptyX509TrustManager$object {
	_jc_gnu_java_net_EmptyX509TrustManager$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_net_EmptyX509TrustManager$vtype	*vtype;
	_jc_gnu_java_net_EmptyX509TrustManager$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_net_EmptyX509TrustManager$vtype _jc_gnu_java_net_EmptyX509TrustManager$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_net_EmptyX509TrustManager, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_net_EmptyX509TrustManager$class_object;

#endif	/* _JC_gnu_java_net_EmptyX509TrustManager_H_ */
